
import { useState } from 'react';
import { Button } from '@/components/ui/button';
import { Download } from 'lucide-react';
import {
  DropdownMenu,
  DropdownMenuContent,
  DropdownMenuItem,
  DropdownMenuTrigger,
} from '@/components/ui/dropdown-menu';
import jsPDF from 'jspdf';
import autoTable from 'jspdf-autotable';

interface Task {
  id: string;
  task_name: string;
  description: string;
  priority: string;
  due_date: string | null;
  status: string;
}

interface ExportOptionsProps {
  tasks: Task[];
}

export const ExportOptions = ({ tasks }: ExportOptionsProps) => {
  const [exporting, setExporting] = useState(false);

  const exportToCsv = () => {
    try {
      setExporting(true);
      
      const headers = ['Task Name', 'Description', 'Priority', 'Due Date', 'Status'];
      
      const csvContent = [
        headers.join(','),
        ...tasks.map(task => {
          return [
            `"${task.task_name.replace(/"/g, '""')}"`,
            `"${task.description?.replace(/"/g, '""') || ''}"`,
            `"${task.priority}"`,
            `"${task.due_date ? new Date(task.due_date).toLocaleDateString() : ''}"`,
            `"${task.status}"`
          ].join(',');
        })
      ].join('\n');
      
      const blob = new Blob([csvContent], { type: 'text/csv;charset=utf-8;' });
      const url = URL.createObjectURL(blob);
      const link = document.createElement('a');
      link.setAttribute('href', url);
      link.setAttribute('download', `tasks_export_${new Date().toISOString().split('T')[0]}.csv`);
      document.body.appendChild(link);
      link.click();
      document.body.removeChild(link);
    } catch (error) {
      console.error('Error exporting to CSV:', error);
    } finally {
      setExporting(false);
    }
  };

  const exportToPdf = () => {
    try {
      setExporting(true);
      
      const doc = new jsPDF();
      
      // Add title
      doc.setFontSize(16);
      doc.text('Policy Tasks Report', 14, 20);
      
      // Add date
      doc.setFontSize(10);
      doc.text(`Generated on: ${new Date().toLocaleDateString()}`, 14, 26);
      
      // Prepare data for table
      const tableData = tasks.map(task => [
        task.task_name,
        task.description?.length > 60 
          ? task.description.substring(0, 60) + '...' 
          : task.description || '',
        task.priority,
        task.due_date ? new Date(task.due_date).toLocaleDateString() : '',
        task.status
      ]);
      
      // Create table
      autoTable(doc, {
        head: [['Task Name', 'Description', 'Priority', 'Due Date', 'Status']],
        body: tableData,
        startY: 32,
        headStyles: { fillColor: [66, 66, 66] },
        margin: { top: 30 },
        styles: { overflow: 'linebreak' },
        columnStyles: {
          0: { cellWidth: 50 },
          1: { cellWidth: 70 },
        },
      });
      
      // Save the PDF
      doc.save(`tasks_export_${new Date().toISOString().split('T')[0]}.pdf`);
    } catch (error) {
      console.error('Error exporting to PDF:', error);
    } finally {
      setExporting(false);
    }
  };

  return (
    <DropdownMenu>
      <DropdownMenuTrigger asChild>
        <Button variant="outline" className="flex items-center">
          <Download className="mr-2 h-4 w-4" />
          Export
        </Button>
      </DropdownMenuTrigger>
      <DropdownMenuContent align="end">
        <DropdownMenuItem onClick={exportToCsv} disabled={exporting || tasks.length === 0}>
          Export as CSV
        </DropdownMenuItem>
        <DropdownMenuItem onClick={exportToPdf} disabled={exporting || tasks.length === 0}>
          Export as PDF
        </DropdownMenuItem>
      </DropdownMenuContent>
    </DropdownMenu>
  );
};
