
import { useState } from 'react';
import { Card, CardContent, CardFooter, CardHeader, CardTitle } from '@/components/ui/card';
import { Button } from '@/components/ui/button';
import { Badge } from '@/components/ui/badge';
import { 
  MoreVertical, 
  Calendar, 
  FileText, 
  Check, 
  X, 
  AlertCircle,
  Clock
} from 'lucide-react';
import {
  DropdownMenu,
  DropdownMenuContent,
  DropdownMenuItem,
  DropdownMenuTrigger,
} from '@/components/ui/dropdown-menu';

interface Task {
  id: string;
  task_name: string;
  description: string;
  priority: string;
  due_date: string | null;
  status: string;
}

interface TaskCardProps {
  task: Task;
  documentName: string;
  onStatusChange: (status: string) => void;
}

export const TaskCard = ({ task, documentName, onStatusChange }: TaskCardProps) => {
  const [expanded, setExpanded] = useState(false);

  const getPriorityIcon = () => {
    switch (task.priority.toLowerCase()) {
      case 'high':
        return <AlertCircle className="h-4 w-4 text-red-500" />;
      case 'medium':
        return <Clock className="h-4 w-4 text-amber-500" />;
      case 'low':
        return <Check className="h-4 w-4 text-green-500" />;
      default:
        return null;
    }
  };

  const getPriorityBadge = () => {
    switch (task.priority.toLowerCase()) {
      case 'high':
        return <Badge variant="destructive" className="ml-2">{task.priority}</Badge>;
      case 'medium':
        return <Badge variant="default" className="ml-2">{task.priority}</Badge>;
      case 'low':
        return <Badge variant="secondary" className="ml-2">{task.priority}</Badge>;
      default:
        return <Badge variant="outline" className="ml-2">{task.priority}</Badge>;
    }
  };

  const getStatusBadge = () => {
    switch (task.status.toLowerCase()) {
      case 'completed':
        return <Badge className="bg-green-500 ml-2">{task.status}</Badge>;
      case 'in progress':
        return <Badge className="bg-blue-500 ml-2">{task.status}</Badge>;
      case 'open':
        return <Badge variant="outline" className="ml-2">{task.status}</Badge>;
      default:
        return <Badge variant="outline" className="ml-2">{task.status}</Badge>;
    }
  };

  return (
    <Card className={`overflow-hidden transition-shadow hover:shadow-md ${
      task.status === 'Completed' ? 'bg-muted/30' : ''
    }`}>
      <CardHeader className="p-4 pb-0 flex flex-row items-start justify-between">
        <div>
          <CardTitle className="text-base line-clamp-2">
            {task.task_name}
          </CardTitle>
          <div className="flex flex-wrap items-center text-xs text-muted-foreground mt-1">
            <div className="flex items-center mr-3">
              {getPriorityIcon()}
              <span className="ml-1">{task.priority}</span>
            </div>
            <div className="flex items-center">
              <FileText className="h-3 w-3 mr-1" />
              <span className="truncate max-w-[120px]">{documentName}</span>
            </div>
          </div>
        </div>
        <DropdownMenu>
          <DropdownMenuTrigger asChild>
            <Button variant="ghost" size="icon" className="h-8 w-8">
              <MoreVertical className="h-4 w-4" />
            </Button>
          </DropdownMenuTrigger>
          <DropdownMenuContent align="end">
            {task.status !== 'Completed' && (
              <DropdownMenuItem onClick={() => onStatusChange('Completed')}>
                <Check className="mr-2 h-4 w-4" />
                Mark as completed
              </DropdownMenuItem>
            )}
            {task.status === 'Completed' && (
              <DropdownMenuItem onClick={() => onStatusChange('Open')}>
                <X className="mr-2 h-4 w-4" />
                Mark as open
              </DropdownMenuItem>
            )}
            {task.status !== 'In Progress' && task.status !== 'Completed' && (
              <DropdownMenuItem onClick={() => onStatusChange('In Progress')}>
                <Clock className="mr-2 h-4 w-4" />
                Mark as in progress
              </DropdownMenuItem>
            )}
          </DropdownMenuContent>
        </DropdownMenu>
      </CardHeader>
      <CardContent className="p-4">
        <div className={`text-sm ${expanded ? '' : 'line-clamp-2'}`}>
          {task.description}
        </div>
        {task.description && task.description.length > 100 && (
          <Button 
            variant="link" 
            className="p-0 h-auto text-xs mt-1" 
            onClick={() => setExpanded(!expanded)}
          >
            {expanded ? 'Show less' : 'Show more'}
          </Button>
        )}
      </CardContent>
      <CardFooter className="p-4 pt-0 flex justify-between">
        <div className="flex items-center text-xs">
          {task.due_date && (
            <div className="flex items-center mr-2">
              <Calendar className="h-3 w-3 mr-1" />
              <span>
                {new Date(task.due_date).toLocaleDateString()}
              </span>
            </div>
          )}
        </div>
        {getStatusBadge()}
      </CardFooter>
    </Card>
  );
};
