
import { useState } from 'react';
import { useAuth } from '@/contexts/AuthContext';
import { supabase } from '@/integrations/supabase/client';
import { useToast } from '@/hooks/use-toast';
import { Upload, FileIcon, Loader2, X } from 'lucide-react';
import { Button } from '@/components/ui/button';
import { Progress } from '@/components/ui/progress';

interface UploadSectionProps {
  onUploadComplete: () => void;
}

const UploadSection = ({ onUploadComplete }: UploadSectionProps) => {
  const { user } = useAuth();
  const { toast } = useToast();
  const [file, setFile] = useState<File | null>(null);
  const [uploading, setUploading] = useState(false);
  const [uploadProgress, setUploadProgress] = useState(0);

  const allowedFileTypes = [
    'application/pdf',
    'application/vnd.openxmlformats-officedocument.wordprocessingml.document'
  ];

  const handleFileChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    if (e.target.files && e.target.files[0]) {
      const selectedFile = e.target.files[0];
      
      if (!allowedFileTypes.includes(selectedFile.type)) {
        toast({
          title: 'Invalid file type',
          description: 'Please upload a PDF or DOCX file',
          variant: 'destructive',
        });
        return;
      }
      
      setFile(selectedFile);
    }
  };

  const clearFile = () => {
    setFile(null);
  };

  const handleUpload = async () => {
    if (!file || !user) return;
    
    try {
      setUploading(true);
      setUploadProgress(0);
      
      // First, create an entry in the uploads table
      const fileName = file.name;
      const fileType = file.type;
      const filePath = `${user.id}/${Date.now()}_${fileName}`;
      
      const { data: uploadData, error: uploadError } = await supabase
        .from('uploads')
        .insert({
          user_id: user.id,
          file_name: fileName,
          file_path: filePath,
          file_type: fileType,
          status: 'Processing'
        })
        .select()
        .single();
      
      if (uploadError) throw uploadError;
      
      // Simulate progress for a better UX
      const progressInterval = setInterval(() => {
        setUploadProgress((prev) => {
          const increment = Math.random() * 10;
          const newProgress = Math.min(prev + increment, 90);
          return newProgress;
        });
      }, 300);
      
      // Upload the file to storage
      const { error: storageError } = await supabase
        .storage
        .from('documents')
        .upload(filePath, file);
        
      clearInterval(progressInterval);
      
      if (storageError) throw storageError;
      
      // Call the edge function to process the document
      const processingResponse = await supabase.functions.invoke('process-document', {
        body: {
          uploadId: uploadData.id,
          userId: user.id,
          filePath: filePath,
          fileType: fileType
        }
      });
      
      if (processingResponse.error) throw new Error(processingResponse.error.message);
      
      setUploadProgress(100);
      
      toast({
        title: 'Upload successful',
        description: 'Your document is now being processed',
      });
      
      // Clear file and reset progress after 1 second
      setTimeout(() => {
        setFile(null);
        setUploadProgress(0);
        onUploadComplete();
      }, 1000);
      
    } catch (error: any) {
      console.error('Upload error:', error);
      toast({
        title: 'Upload failed',
        description: error.message || 'An error occurred while uploading the document',
        variant: 'destructive',
      });
    } finally {
      setUploading(false);
    }
  };

  return (
    <div className="space-y-4">
      {!file ? (
        <div className="border-2 border-dashed rounded-lg p-8 text-center">
          <label className="flex flex-col items-center justify-center cursor-pointer space-y-3">
            <Upload className="h-10 w-10 text-muted-foreground" />
            <span className="text-lg font-medium">Drag and drop or click to upload</span>
            <span className="text-sm text-muted-foreground">PDF or DOCX files only</span>
            <input 
              type="file" 
              className="hidden" 
              accept=".pdf,.docx,application/pdf,application/vnd.openxmlformats-officedocument.wordprocessingml.document" 
              onChange={handleFileChange}
            />
            <Button variant="outline" type="button">
              Select file
            </Button>
          </label>
        </div>
      ) : (
        <div className="border rounded-lg p-6 space-y-4">
          <div className="flex items-center justify-between">
            <div className="flex items-center gap-3">
              <div className="bg-primary/10 p-2 rounded">
                <FileIcon className="h-6 w-6 text-primary" />
              </div>
              <div>
                <p className="font-medium">{file.name}</p>
                <p className="text-sm text-muted-foreground">
                  {(file.size / 1024 / 1024).toFixed(2)} MB
                </p>
              </div>
            </div>
            <Button 
              variant="ghost" 
              size="icon" 
              onClick={clearFile}
              disabled={uploading}
            >
              <X className="h-4 w-4" />
            </Button>
          </div>
          
          {uploading && (
            <div className="space-y-2">
              <Progress value={uploadProgress} className="h-2" />
              <p className="text-xs text-muted-foreground">{uploadProgress.toFixed(0)}% complete</p>
            </div>
          )}
          
          <div className="flex justify-end">
            <Button
              onClick={handleUpload}
              disabled={uploading}
              className="flex items-center gap-2"
            >
              {uploading ? (
                <>
                  <Loader2 className="h-4 w-4 animate-spin" />
                  Uploading...
                </>
              ) : (
                <>
                  <Upload className="h-4 w-4" />
                  Upload Document
                </>
              )}
            </Button>
          </div>
        </div>
      )}
      
      <div className="text-sm text-muted-foreground">
        <p>After uploading, your document will be automatically processed to extract actionable tasks.</p>
      </div>
    </div>
  );
};

export default UploadSection;
