
import { useState, useEffect } from 'react';
import { useAuth } from '@/contexts/AuthContext';
import { useToast } from '@/hooks/use-toast';
import { supabase } from '@/integrations/supabase/client';
import { Upload, FilePlus, FileText, AlertTriangle } from 'lucide-react';
import { Button } from '@/components/ui/button';
import { Card, CardContent, CardDescription, CardFooter, CardHeader, CardTitle } from '@/components/ui/card';
import UploadSection from '@/components/UploadSection';
import TaskList from '@/components/TaskList';

const Dashboard = () => {
  const { user } = useAuth();
  const { toast } = useToast();
  const [activeTab, setActiveTab] = useState<'upload' | 'tasks'>('upload');
  const [uploadCount, setUploadCount] = useState(0);
  const [taskCount, setTaskCount] = useState(0);
  const [recentUploads, setRecentUploads] = useState<any[]>([]);
  const [processingUploads, setProcessingUploads] = useState<number>(0);

  useEffect(() => {
    if (user) {
      fetchDashboardData();
    }
  }, [user]);

  const fetchDashboardData = async () => {
    try {
      // Get upload count
      const { count: uploadCountData, error: uploadCountError } = await supabase
        .from('uploads')
        .select('*', { count: 'exact', head: true })
        .eq('user_id', user?.id);

      if (uploadCountError) throw uploadCountError;
      setUploadCount(uploadCountData || 0);

      // Get task count
      const { count: taskCountData, error: taskCountError } = await supabase
        .from('tasks')
        .select('*', { count: 'exact', head: true })
        .eq('user_id', user?.id);

      if (taskCountError) throw taskCountError;
      setTaskCount(taskCountData || 0);

      // Get recent uploads
      const { data: recentUploadsData, error: recentUploadsError } = await supabase
        .from('uploads')
        .select('*')
        .eq('user_id', user?.id)
        .order('created_at', { ascending: false })
        .limit(5);

      if (recentUploadsError) throw recentUploadsError;
      setRecentUploads(recentUploadsData || []);

      // Get processing uploads count
      const { count: processingCount, error: processingError } = await supabase
        .from('uploads')
        .select('*', { count: 'exact', head: true })
        .eq('user_id', user?.id)
        .eq('status', 'Processing');

      if (processingError) throw processingError;
      setProcessingUploads(processingCount || 0);
    } catch (error) {
      console.error('Error fetching dashboard data:', error);
      toast({
        title: 'Error',
        description: 'Failed to load dashboard data',
        variant: 'destructive',
      });
    }
  };

  return (
    <div className="container mx-auto px-4 py-8">
      <h1 className="text-3xl font-bold mb-6">Dashboard</h1>
      
      <div className="grid grid-cols-1 md:grid-cols-3 gap-4 mb-8">
        <Card>
          <CardHeader className="pb-2">
            <CardTitle className="text-lg">Documents</CardTitle>
            <CardDescription>Total uploaded documents</CardDescription>
          </CardHeader>
          <CardContent>
            <p className="text-3xl font-bold">{uploadCount}</p>
          </CardContent>
        </Card>
        
        <Card>
          <CardHeader className="pb-2">
            <CardTitle className="text-lg">Tasks</CardTitle>
            <CardDescription>Extracted actionable items</CardDescription>
          </CardHeader>
          <CardContent>
            <p className="text-3xl font-bold">{taskCount}</p>
          </CardContent>
        </Card>

        <Card>
          <CardHeader className="pb-2 flex flex-row items-center justify-between space-y-0">
            <div>
              <CardTitle className="text-lg">Processing</CardTitle>
              <CardDescription>Documents being analyzed</CardDescription>
            </div>
            {processingUploads > 0 && (
              <div className="rounded-full bg-amber-500/20 p-1">
                <AlertTriangle className="h-5 w-5 text-amber-500" />
              </div>
            )}
          </CardHeader>
          <CardContent>
            <p className="text-3xl font-bold">{processingUploads}</p>
          </CardContent>
        </Card>
      </div>

      <div className="flex flex-col md:flex-row gap-4 mb-8">
        <Button 
          variant={activeTab === 'upload' ? 'default' : 'outline'} 
          onClick={() => setActiveTab('upload')}
          className="flex items-center gap-2"
        >
          <Upload className="h-4 w-4" />
          Upload Document
        </Button>
        
        <Button 
          variant={activeTab === 'tasks' ? 'default' : 'outline'} 
          onClick={() => setActiveTab('tasks')}
          className="flex items-center gap-2"
        >
          <FileText className="h-4 w-4" />
          View Tasks
        </Button>
      </div>

      {activeTab === 'upload' ? (
        <div className="space-y-6">
          <Card>
            <CardHeader>
              <CardTitle>Upload Policy Document</CardTitle>
              <CardDescription>
                Upload your IT security or compliance policy documents to extract actionable tasks
              </CardDescription>
            </CardHeader>
            <CardContent>
              <UploadSection onUploadComplete={fetchDashboardData} />
            </CardContent>
          </Card>

          {recentUploads.length > 0 && (
            <Card>
              <CardHeader>
                <CardTitle>Recent Uploads</CardTitle>
                <CardDescription>
                  Your most recent document uploads
                </CardDescription>
              </CardHeader>
              <CardContent>
                <div className="space-y-4">
                  {recentUploads.map((upload) => (
                    <div key={upload.id} className="flex items-center justify-between border-b pb-4 last:border-0">
                      <div className="flex items-center gap-3">
                        <FilePlus className="h-6 w-6 text-muted-foreground" />
                        <div>
                          <p className="font-medium">{upload.file_name}</p>
                          <p className="text-sm text-muted-foreground">
                            {new Date(upload.created_at).toLocaleDateString()}
                          </p>
                        </div>
                      </div>
                      <div>
                        <span className={`px-2 py-1 rounded-full text-xs ${
                          upload.status === 'Completed' 
                            ? 'bg-green-100 text-green-800 dark:bg-green-900/30 dark:text-green-400' 
                            : 'bg-amber-100 text-amber-800 dark:bg-amber-900/30 dark:text-amber-400'
                        }`}>
                          {upload.status}
                        </span>
                      </div>
                    </div>
                  ))}
                </div>
              </CardContent>
            </Card>
          )}
        </div>
      ) : (
        <TaskList />
      )}
    </div>
  );
};

export default Dashboard;
