
import { useState, useEffect, useRef } from 'react';
import { Link } from 'react-router-dom';
import { 
  ShieldCheck, 
  FileText, 
  ClipboardList, 
  Download, 
  CheckCircle2,
  ArrowRight,
  ChevronRight,
  CheckCircle,
  X
} from 'lucide-react';
import { Button } from '@/components/ui/button';
import { Card, CardContent } from '@/components/ui/card';
import { Badge } from '@/components/ui/badge';
import Header from '@/components/Header';

const Index = () => {
  const [isVisible, setIsVisible] = useState<{ [key: string]: boolean }>({});
  const refs = {
    hero: useRef<HTMLDivElement>(null),
    features: useRef<HTMLDivElement>(null),
    howItWorks: useRef<HTMLDivElement>(null),
    pricing: useRef<HTMLDivElement>(null),
  };

  useEffect(() => {
    const observerOptions = {
      root: null,
      rootMargin: '0px',
      threshold: 0.1,
    };

    const observerCallback = (entries: IntersectionObserverEntry[]) => {
      entries.forEach(entry => {
        if (entry.target.id) {
          setIsVisible(prev => ({
            ...prev,
            [entry.target.id]: entry.isIntersecting,
          }));
        }
      });
    };

    const observer = new IntersectionObserver(observerCallback, observerOptions);
    
    Object.values(refs).forEach(ref => {
      if (ref.current) {
        observer.observe(ref.current);
      }
    });

    return () => {
      observer.disconnect();
    };
  }, []);

  const features = [
    {
      icon: <FileText className="w-6 h-6 text-primary" />,
      title: 'Document Upload',
      description: 'Upload your policy documents in PDF or DOCX format for instant processing.'
    },
    {
      icon: <ClipboardList className="w-6 h-6 text-primary" />,
      title: 'Task Extraction',
      description: 'Our smart algorithm identifies and extracts actionable tasks from complex documents.'
    },
    {
      icon: <CheckCircle2 className="w-6 h-6 text-primary" />,
      title: 'Task Prioritization',
      description: 'Review, edit, and prioritize extracted tasks to create an effective action plan.'
    },
    {
      icon: <Download className="w-6 h-6 text-primary" />,
      title: 'Export for Implementation',
      description: 'Export tasks to CSV for easy integration with your team\'s workflow tools.'
    }
  ];

  const steps = [
    {
      number: '01',
      title: 'Upload',
      description: 'Upload your IT security or compliance policy document in PDF or Word format.'
    },
    {
      number: '02',
      title: 'Analyze',
      description: 'Our system scans the document to extract actionable tasks, deadlines, and assigned roles.'
    },
    {
      number: '03',
      title: 'Review & Prioritize',
      description: 'Review the extracted tasks, make edits if needed, and assign priorities.'
    },
    {
      number: '04',
      title: 'Export',
      description: 'Export your tasks as CSV to share with your team or import into your task management system.'
    }
  ];

  const plans = [
    {
      name: 'Free',
      price: '$0',
      description: 'For individuals and small teams',
      features: [
        '3 document uploads per month',
        'Basic task extraction',
        'CSV export',
        'Standard support'
      ],
      limitations: [
        'No document storage',
        'No team collaboration',
        'No task history'
      ],
      cta: 'Get Started',
      highlight: false
    },
    {
      name: 'Pro',
      price: '$19',
      period: '/month',
      description: 'For security professionals',
      features: [
        'Unlimited document uploads',
        'Advanced task extraction',
        'CSV & PDF exports',
        'Document storage',
        'Priority support',
        'Task history & tracking'
      ],
      limitations: [],
      cta: 'Start Free Trial',
      highlight: true
    },
    {
      name: 'Enterprise',
      price: 'Custom',
      description: 'For organizations with advanced needs',
      features: [
        'Everything in Pro',
        'API access',
        'Custom integrations',
        'Dedicated support',
        'SSO authentication',
        'Compliance reporting'
      ],
      limitations: [],
      cta: 'Contact Sales',
      highlight: false
    }
  ];

  return (
    <div className="min-h-screen">
      <Header />
      
      {/* Hero Section */}
      <section
        ref={refs.hero}
        id="hero"
        className={`pt-24 pb-16 md:pt-32 md:pb-24 transition-opacity duration-1000 ${isVisible.hero ? 'opacity-100' : 'opacity-0'}`}
      >
        <div className="container mx-auto px-4 sm:px-6 lg:px-8">
          <div className="max-w-4xl mx-auto text-center">
            <Badge 
              variant="outline" 
              className="mb-6 px-4 py-1 rounded-full backdrop-blur-sm bg-background/30 shadow-sm animate-fade-in"
            >
              Streamline Your Security Compliance
            </Badge>
            
            <h1 className="text-4xl md:text-5xl lg:text-6xl font-bold mb-6 tracking-tight text-balance animate-fade-up">
              Turn Policy Documents Into <span className="text-primary">Actionable Tasks</span>
            </h1>
            
            <p className="text-xl text-muted-foreground mb-10 max-w-2xl mx-auto text-balance animate-fade-up" style={{animationDelay: '100ms'}}>
              SecuPolicy extracts actionable tasks from IT security and compliance policies, 
              helping your team implement requirements quickly and accurately.
            </p>
            
            <div className="flex flex-col sm:flex-row justify-center gap-4 animate-fade-up" style={{animationDelay: '200ms'}}>
              <Button asChild size="lg" className="rounded-full">
                <Link to="/dashboard">Try SecuPolicy Free</Link>
              </Button>
              <Button asChild variant="outline" size="lg" className="rounded-full">
                <a href="#howItWorks">How It Works <ChevronRight className="ml-1 w-4 h-4" /></a>
              </Button>
            </div>
          </div>
        </div>
      </section>
      
      {/* Illustration */}
      <section className="py-12 bg-gradient-to-b from-transparent to-muted/30">
        <div className="container mx-auto px-4 sm:px-6 lg:px-8">
          <div className="glass-panel max-w-5xl mx-auto shadow-xl overflow-hidden rounded-3xl animate-scale-in">
            <div className="relative">
              <div className="px-6 py-4 border-b border-border flex justify-between items-center bg-muted/20">
                <div className="flex space-x-2">
                  <div className="w-3 h-3 rounded-full bg-red-400"></div>
                  <div className="w-3 h-3 rounded-full bg-yellow-400"></div>
                  <div className="w-3 h-3 rounded-full bg-green-400"></div>
                </div>
                <div className="text-sm font-medium">SecuPolicy Dashboard</div>
                <div></div>
              </div>
              <div className="aspect-[16/9] bg-gradient-to-br from-background to-muted overflow-hidden">
                <div className="p-8 grid grid-cols-1 md:grid-cols-2 gap-6 h-full">
                  <div className="flex flex-col gap-4">
                    <div className="glass-panel p-4 shadow-sm">
                      <h3 className="text-base font-medium mb-3">Task Overview</h3>
                      <div className="grid grid-cols-2 gap-3">
                        <div className="bg-white/30 dark:bg-black/10 rounded-lg p-3">
                          <div className="text-sm text-muted-foreground">Total Tasks</div>
                          <div className="text-2xl font-semibold">24</div>
                        </div>
                        <div className="bg-white/30 dark:bg-black/10 rounded-lg p-3">
                          <div className="text-sm text-muted-foreground">High Priority</div>
                          <div className="text-2xl font-semibold">8</div>
                        </div>
                        <div className="bg-white/30 dark:bg-black/10 rounded-lg p-3">
                          <div className="text-sm text-muted-foreground">In Progress</div>
                          <div className="text-2xl font-semibold">10</div>
                        </div>
                        <div className="bg-white/30 dark:bg-black/10 rounded-lg p-3">
                          <div className="text-sm text-muted-foreground">Completed</div>
                          <div className="text-2xl font-semibold">6</div>
                        </div>
                      </div>
                    </div>
                    <div className="glass-panel p-4 shadow-sm flex-grow">
                      <div className="flex justify-between items-center mb-3">
                        <h3 className="text-base font-medium">Recent Uploads</h3>
                        <Button variant="ghost" size="sm" className="h-8">
                          View All
                        </Button>
                      </div>
                      <div className="space-y-3">
                        <div className="bg-white/30 dark:bg-black/10 rounded-lg p-3 flex items-center">
                          <FileText className="w-5 h-5 text-primary mr-3" />
                          <div>
                            <div className="text-sm font-medium">GDPR_Compliance.pdf</div>
                            <div className="text-xs text-muted-foreground">7 tasks extracted</div>
                          </div>
                        </div>
                        <div className="bg-white/30 dark:bg-black/10 rounded-lg p-3 flex items-center">
                          <FileText className="w-5 h-5 text-primary mr-3" />
                          <div>
                            <div className="text-sm font-medium">HIPAA_Security.docx</div>
                            <div className="text-xs text-muted-foreground">12 tasks extracted</div>
                          </div>
                        </div>
                        <div className="bg-white/30 dark:bg-black/10 rounded-lg p-3 flex items-center">
                          <FileText className="w-5 h-5 text-primary mr-3" />
                          <div>
                            <div className="text-sm font-medium">ISO27001_Controls.pdf</div>
                            <div className="text-xs text-muted-foreground">5 tasks extracted</div>
                          </div>
                        </div>
                      </div>
                    </div>
                  </div>
                  <div className="glass-panel p-4 shadow-sm">
                    <div className="flex justify-between items-center mb-3">
                      <h3 className="text-base font-medium">High Priority Tasks</h3>
                      <Button variant="ghost" size="sm" className="h-8">
                        Filter
                      </Button>
                    </div>
                    <div className="space-y-3">
                      <div className="bg-white/30 dark:bg-black/10 rounded-lg p-3">
                        <div className="flex justify-between mb-1">
                          <div className="text-sm font-medium">Implement MFA for all employees</div>
                          <Badge variant="outline" className="text-xs bg-red-100 text-red-800 dark:bg-red-900/30 dark:text-red-300">High</Badge>
                        </div>
                        <div className="text-xs text-muted-foreground flex items-center justify-between">
                          <span>IT Security</span>
                          <span>Due: Sept 30, 2024</span>
                        </div>
                      </div>
                      <div className="bg-white/30 dark:bg-black/10 rounded-lg p-3">
                        <div className="flex justify-between mb-1">
                          <div className="text-sm font-medium">Update privacy policies</div>
                          <Badge variant="outline" className="text-xs bg-red-100 text-red-800 dark:bg-red-900/30 dark:text-red-300">High</Badge>
                        </div>
                        <div className="text-xs text-muted-foreground flex items-center justify-between">
                          <span>Legal Department</span>
                          <span>Due: Aug 15, 2024</span>
                        </div>
                      </div>
                      <div className="bg-white/30 dark:bg-black/10 rounded-lg p-3">
                        <div className="flex justify-between mb-1">
                          <div className="text-sm font-medium">Implement data breach notification</div>
                          <Badge variant="outline" className="text-xs bg-red-100 text-red-800 dark:bg-red-900/30 dark:text-red-300">High</Badge>
                        </div>
                        <div className="text-xs text-muted-foreground flex items-center justify-between">
                          <span>Security Team</span>
                          <span>Due: Oct 20, 2024</span>
                        </div>
                      </div>
                      <div className="bg-white/30 dark:bg-black/10 rounded-lg p-3">
                        <div className="flex justify-between mb-1">
                          <div className="text-sm font-medium">Conduct annual risk assessment</div>
                          <Badge variant="outline" className="text-xs bg-red-100 text-red-800 dark:bg-red-900/30 dark:text-red-300">High</Badge>
                        </div>
                        <div className="text-xs text-muted-foreground flex items-center justify-between">
                          <span>Compliance Officer</span>
                          <span>Due: Dec 31, 2024</span>
                        </div>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
      </section>
      
      {/* Features Section */}
      <section
        ref={refs.features}
        id="features"
        className={`py-16 md:py-24 transition-opacity duration-1000 ${isVisible.features ? 'opacity-100' : 'opacity-0'}`}
      >
        <div className="container mx-auto px-4 sm:px-6 lg:px-8">
          <div className="max-w-3xl mx-auto text-center mb-16">
            <Badge variant="outline" className="mb-4 px-3 py-1 rounded-full">Features</Badge>
            <h2 className="text-3xl md:text-4xl font-bold mb-6">
              Streamline Security Policy Implementation
            </h2>
            <p className="text-lg text-muted-foreground">
              SecuPolicy extracts tasks from complex policy documents, making compliance manageable and actionable.
            </p>
          </div>
          
          <div className="grid grid-cols-1 md:grid-cols-2 gap-8 max-w-5xl mx-auto">
            {features.map((feature, index) => (
              <div key={index} className="glass-panel p-6 hover-lift">
                <div className="w-12 h-12 rounded-full bg-primary/10 flex items-center justify-center mb-4">
                  {feature.icon}
                </div>
                <h3 className="text-xl font-semibold mb-2">{feature.title}</h3>
                <p className="text-muted-foreground">{feature.description}</p>
              </div>
            ))}
          </div>
        </div>
      </section>
      
      {/* How It Works Section */}
      <section
        ref={refs.howItWorks}
        id="howItWorks"
        className={`py-16 md:py-24 bg-muted/30 transition-opacity duration-1000 ${isVisible.howItWorks ? 'opacity-100' : 'opacity-0'}`}
      >
        <div className="container mx-auto px-4 sm:px-6 lg:px-8">
          <div className="max-w-3xl mx-auto text-center mb-16">
            <Badge variant="outline" className="mb-4 px-3 py-1 rounded-full">Process</Badge>
            <h2 className="text-3xl md:text-4xl font-bold mb-6">
              How SecuPolicy Works
            </h2>
            <p className="text-lg text-muted-foreground">
              Our simplified workflow transforms complex policy documents into clear, actionable tasks.
            </p>
          </div>
          
          <div className="max-w-5xl mx-auto grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-8">
            {steps.map((step, index) => (
              <div key={index} className="relative">
                <div className="glass-panel p-6 hover-lift h-full flex flex-col">
                  <div className="text-3xl font-bold text-primary/20 mb-4">
                    {step.number}
                  </div>
                  <h3 className="text-xl font-semibold mb-3">{step.title}</h3>
                  <p className="text-muted-foreground">{step.description}</p>
                  
                  {index < steps.length - 1 && (
                    <div className="hidden lg:block absolute top-1/2 -right-4 transform -translate-y-1/2 z-10">
                      <ArrowRight className="w-6 h-6 text-muted-foreground/40" />
                    </div>
                  )}
                </div>
              </div>
            ))}
          </div>
          
          <div className="mt-16 text-center">
            <Button asChild size="lg" className="rounded-full">
              <Link to="/dashboard">Try It Now</Link>
            </Button>
          </div>
        </div>
      </section>
      
      {/* Pricing Section */}
      <section
        ref={refs.pricing}
        id="pricing"
        className={`py-16 md:py-24 transition-opacity duration-1000 ${isVisible.pricing ? 'opacity-100' : 'opacity-0'}`}
      >
        <div className="container mx-auto px-4 sm:px-6 lg:px-8">
          <div className="max-w-3xl mx-auto text-center mb-16">
            <Badge variant="outline" className="mb-4 px-3 py-1 rounded-full">Pricing</Badge>
            <h2 className="text-3xl md:text-4xl font-bold mb-6">
              Choose the Right Plan for Your Team
            </h2>
            <p className="text-lg text-muted-foreground">
              From individuals to enterprise teams, we have options to fit your needs and budget.
            </p>
          </div>
          
          <div className="max-w-6xl mx-auto grid grid-cols-1 md:grid-cols-3 gap-8">
            {plans.map((plan, index) => (
              <div key={index} className={`
                relative glass-panel p-6 flex flex-col 
                ${plan.highlight ? 'ring-2 ring-primary/20 shadow-lg' : ''}
              `}>
                {plan.highlight && (
                  <div className="absolute top-0 right-0 transform translate-x-4 -translate-y-4">
                    <Badge className="bg-primary text-white px-3 py-1 rounded-full">
                      Most Popular
                    </Badge>
                  </div>
                )}
                
                <div className="mb-6">
                  <h3 className="text-xl font-semibold mb-1">{plan.name}</h3>
                  <div className="flex items-end gap-1 mb-2">
                    <span className="text-3xl font-bold">{plan.price}</span>
                    {plan.period && <span className="text-muted-foreground">{plan.period}</span>}
                  </div>
                  <p className="text-sm text-muted-foreground">{plan.description}</p>
                </div>
                
                <div className="space-y-4 mb-8 flex-grow">
                  <ul className="space-y-2">
                    {plan.features.map((feature, fIndex) => (
                      <li key={fIndex} className="flex items-start">
                        <CheckCircle className="w-5 h-5 text-green-500 shrink-0 mr-2" />
                        <span className="text-sm">{feature}</span>
                      </li>
                    ))}
                  </ul>
                  
                  {plan.limitations.length > 0 && (
                    <ul className="space-y-2 pt-4 border-t border-border">
                      {plan.limitations.map((limitation, lIndex) => (
                        <li key={lIndex} className="flex items-start">
                          <X className="w-5 h-5 text-muted-foreground shrink-0 mr-2" />
                          <span className="text-sm text-muted-foreground">{limitation}</span>
                        </li>
                      ))}
                    </ul>
                  )}
                </div>
                
                <Button 
                  asChild 
                  variant={plan.highlight ? "default" : "outline"}
                  className={`rounded-full w-full ${plan.highlight ? "shadow-md" : ""}`}
                >
                  <Link to={plan.name === 'Enterprise' ? "#" : "/dashboard"}>
                    {plan.cta}
                  </Link>
                </Button>
              </div>
            ))}
          </div>
        </div>
      </section>
      
      {/* CTA Section */}
      <section className="py-16 md:py-24 bg-muted/30">
        <div className="container mx-auto px-4 sm:px-6 lg:px-8">
          <div className="max-w-4xl mx-auto glass-panel p-10 rounded-3xl text-center">
            <div className="w-16 h-16 bg-primary/10 rounded-full flex items-center justify-center mx-auto mb-6">
              <ShieldCheck className="w-8 h-8 text-primary" />
            </div>
            <h2 className="text-3xl md:text-4xl font-bold mb-4">
              Ready to Streamline Your Compliance?
            </h2>
            <p className="text-lg text-muted-foreground mb-8 max-w-2xl mx-auto">
              Start extracting actionable tasks from your security and compliance policies today. 
              No credit card required to get started.
            </p>
            <Button asChild size="lg" className="rounded-full px-8">
              <Link to="/dashboard">Try SecuPolicy Free</Link>
            </Button>
          </div>
        </div>
      </section>
      
      {/* Footer */}
      <footer className="py-12 border-t">
        <div className="container mx-auto px-4 sm:px-6 lg:px-8">
          <div className="grid grid-cols-1 md:grid-cols-4 gap-8 mb-8">
            <div className="md:col-span-2">
              <div className="flex items-center space-x-2 mb-4">
                <ShieldCheck className="w-6 h-6 text-primary" />
                <span className="text-xl font-semibold">SecuPolicy</span>
              </div>
              <p className="text-muted-foreground max-w-sm mb-4">
                Turning IT security and compliance policies into actionable tasks for your team.
              </p>
              <div className="flex space-x-4">
                <a href="#" className="text-muted-foreground hover:text-foreground transition-colors">
                  Twitter
                </a>
                <a href="#" className="text-muted-foreground hover:text-foreground transition-colors">
                  LinkedIn
                </a>
                <a href="#" className="text-muted-foreground hover:text-foreground transition-colors">
                  GitHub
                </a>
              </div>
            </div>
            
            <div>
              <h3 className="font-medium mb-4">Product</h3>
              <ul className="space-y-2">
                <li><a href="#features" className="text-muted-foreground hover:text-foreground transition-colors">Features</a></li>
                <li><a href="#pricing" className="text-muted-foreground hover:text-foreground transition-colors">Pricing</a></li>
                <li><a href="#" className="text-muted-foreground hover:text-foreground transition-colors">Roadmap</a></li>
                <li><a href="#" className="text-muted-foreground hover:text-foreground transition-colors">Changelog</a></li>
              </ul>
            </div>
            
            <div>
              <h3 className="font-medium mb-4">Company</h3>
              <ul className="space-y-2">
                <li><a href="#" className="text-muted-foreground hover:text-foreground transition-colors">About</a></li>
                <li><a href="#" className="text-muted-foreground hover:text-foreground transition-colors">Blog</a></li>
                <li><a href="#" className="text-muted-foreground hover:text-foreground transition-colors">Careers</a></li>
                <li><a href="#" className="text-muted-foreground hover:text-foreground transition-colors">Contact</a></li>
              </ul>
            </div>
          </div>
          
          <div className="border-t pt-8 flex flex-col md:flex-row justify-between items-center">
            <div className="text-sm text-muted-foreground mb-4 md:mb-0">
              © 2024 SecuPolicy. All rights reserved.
            </div>
            <div className="flex space-x-6">
              <a href="#" className="text-sm text-muted-foreground hover:text-foreground transition-colors">
                Privacy Policy
              </a>
              <a href="#" className="text-sm text-muted-foreground hover:text-foreground transition-colors">
                Terms of Service
              </a>
              <a href="#" className="text-sm text-muted-foreground hover:text-foreground transition-colors">
                Cookie Policy
              </a>
            </div>
          </div>
        </div>
      </footer>
    </div>
  );
};

export default Index;
